#include <PIC18F4431_config.h>

#define DC_MOTOR

#include "init.h"
#include "init.c"

#include "delay.h"
#include "delay.c"

#define MAX_CURRENT 1000

/**
 * @note This Example shows how to drive the DC motors via RS485  
 *       After Initialization both motors are halted. 
 *       Speed is increased pressing 1 or 2 from the keyboard.
 *       Pressing '1' increases Motor 1 speed while pressing '2' Motor 2 speed.
 *       Pressing 's' halts the motors.
 *       An USB/RS232 to RS485 is required to run the demo.
 */

//************************************************************
// Main program
//************************************************************

void main (void){

    int motor_1_speed = 0;
    int motor_2_speed = 0;

    unsigned char data;

    board_initialization ();

    initialize_RS485 (BAUD_RATE_19200,RX_INTERRUPT_OFF, TX_INTERRUPT_OFF);

    initialize_DC_motor (SIGNED_MAGNITUDE,PWM_FREQ_10KHZ, MAX_CURRENT);

    while (1) {

        // Waiting for new data

        while (read_data_RS485 (&data) == ERROR_RX_DATA_NOT_READY)
            system_check ();

        ERROR_LED = LED_OFF;

        if (data == '1') {
            motor_1_speed += 10;
            rotate_motor_clockwise (MOTOR_1, motor_1_speed);
        } else

        if (data == '2') {
            motor_2_speed += 10;
            rotate_motor_clockwise (MOTOR_2, motor_2_speed);
        } else

        if (data == 's') {
            stop_motor_rotation (MOTOR_ALL);
            motor_1_speed = 0;
            motor_2_speed = 0;
        } else {
                ERROR_LED = LED_ON;
        }

    }
}



